@@ -396,14 +396,16 @@ class EsHelper:
             }
         return res
 
-    def sync_delete_one(self, route_key, id):
-        path = f"/{route_key}/{id}"
+    def sync_delete_one(self, route_key, id, doc_type="_doc"):
+        path = f"/{route_key}/{doc_type}/{id}"
         url = self.pool.format_url(path)
         res = self.pool.format_es_delete(url=url)
         return res
 
-    def sync_delete_data(self, route_key, params=[]):
-        path = f"/{route_key}/_delete_by_query"
+    def sync_delete_data(self, route_key, params=None, doc_type="_doc"):
+        if params is None:
+            params = []
+        path = f"/{route_key}/{doc_type}/_delete_by_query"
         url = self.pool.format_url(path)
         data = {
             "query": {
@@ -415,8 +417,8 @@ class EsHelper:
         res = self.pool.format_es_delete(url=url, data=data)
         return res
 
-    def sync_update_data(self, route_key, params, new_data: dict):
-        path = f"/{route_key}/_update_by_query"
+    def sync_update_data(self, route_key, params, new_data: dict, doc_type="_doc"):
+        path = f"/{route_key}/{doc_type}/_update_by_query"
         url = self.pool.format_url(path)
         data = {
             "query": {
@@ -435,23 +437,23 @@ class EsHelper:
         res = self.pool.format_es_post(url=url, body=data)
         return res
 
-    def sync_update_one(self, route_key, id, data):
-        path = f"/{route_key}/{id}/_update"
+    def sync_update_one(self, route_key, id, data, doc_type="_doc"):
+        path = f"/{route_key}/{doc_type}/{id}/_update"
         url = self.pool.format_url(path)
         res = self.pool.format_es_post(url, body=data)
         return res
 
-    def sync_insert_one(self, route_key, data, id=None):
+    def sync_insert_one(self, route_key, data, id=None, doc_type="_doc"):
         if id:
-            path = f"/{route_key}/{id}"
+            path = f"/{route_key}/{id}/{doc_type}"
         else:
-            path = f"/{route_key}"
+            path = f"/{route_key}/{doc_type}"
         url = self.pool.format_url(path)
         res = self.pool.format_es_post(url, body=data)
         return res
 
-    def sync_insert_data(self, route_key, data):
-        path = f"/{route_key}/_bulk"
+    def sync_insert_data(self, route_key, data, doc_type="_doc"):
+        path = f"/{route_key}/{doc_type}/_bulk"
         url = self.pool.format_url(path)
         res = self.pool.format_es_post(url, body=data)
         return res
